@@ -2,7 +2,7 @@
  * parser.cpp : SAP configuration file parser
  ****************************************************************************
  * Copyright (C) 1998-2002 VideoLAN
- * $Id: parser.cpp,v 1.5 2003/06/16 15:30:11 zorglub Exp $
+ * $Id: parser.cpp,v 1.6 2003/07/24 16:35:08 nitrox Exp $
  *
  * Authors: Arnaud Schauly <gitan@via.ecp.fr>
  *          Clment Stenac <zorglub@via.ecp.fr>
@@ -108,12 +108,16 @@ char Config::GetScope()
 void Config::strgetb(char *source,char *dest,char delim)
 {
         unsigned long i = 0;
-        while(source[i] != delim && i < strlen(source))
-        {
+        unsigned long j;
+
+        // Cut the line just before the delim char
+        for(i=0; source[i] != delim && i < strlen(source); i++)
                 dest[i]=source[i];
-                i++;
-        }
-        dest[i]=0;
+        dest[i]='\0';
+
+        // Remove the trailing blanks
+        for(j=i-1; dest[j] == ' '|| dest[j] == '\t' || dest[j] == '\n'; j--)
+            dest[j] = '\0';
 }
 
 /********************************************************** 
@@ -160,11 +164,8 @@ int Config::Parse()
         return(-1);
     }
 
-    while(!feof(fd))
+    while(fgets(line,1024,fd))
     {
-        memset(line,'0',1024);
-        fgets(line,1024,fd);
-
         if(!strlen(line))
         {
             break;
@@ -172,37 +173,37 @@ int Config::Parse()
 
         strgetb(line,line,'#'); /* Handle the comments */
 
-	/* Set SAP TTL  (ttl is a member of config) */
+        /* Set SAP TTL  (ttl is a member of config) */
         if(strstr(line,"sap_ttl="))
         {
             strgeta(line,tline,'=');
             ttl=atoi(tline);
         }
-	
-	/* Set SAP IP Version  (ipversion is a member of config) */
+
+        /* Set SAP IP Version  (ipversion is a member of config) */
         if(strstr(line,"sap_ipversion="))
         {
             strgeta(line,tline,'=');
             ipversion=atoi(tline);
         }
 
-	/* Set SAP IPv6 Scope  (scope is a member of config) */
+        /* Set SAP IPv6 Scope  (scope is a member of config) */
         if(strstr(line,"ipv6_scope="))
         {
             strgeta(line,tline,'=');
             scope=strdup(tline);
         }
 
-	/*  Beginning of programs parsing */
+        /*  Beginning of programs parsing */
         if(strstr(line,"[program]"))
         {
             if(something)
             {
                 /* We were in a program with at least one field filled */
-		if (!pp->GetPort().length())
-		{
-		  pp->SetPort(DEFAULT_PORT);
-		}
+                if (!pp->GetPort().length())
+                {
+                    pp->SetPort(DEFAULT_PORT);
+                }
                 Programs.push_back(pp);
                 pp=new Program();
                 something=0;
@@ -257,17 +258,16 @@ int Config::Parse()
             something=1;
             pp->SetAddress(tline);
         }
-	if(strstr(line,"port="))
-	{
-	    strgeta(line,tline,'=');
-	    something=1;
-	    pp->SetPort(tline); 
-	}
+        if(strstr(line,"port="))
+        {
+            strgeta(line,tline,'=');
+            something=1;
+            pp->SetPort(tline); 
+        }
     }
 
-    if(something) 
+    if(something)
     {
- 
      if (!pp->GetPort().length())
      {
           pp->SetPort(DEFAULT_PORT);
