@@ -2,7 +2,7 @@
  * sapserver.cpp : SAP discovery service mini-server
  ****************************************************************************
  * Copyright (C) 1998-2002 VideoLAN
- * $Id: sapserver.cpp,v 1.12 2003/06/16 10:26:47 zorglub Exp $ 
+ * $Id: sapserver.cpp,v 1.13 2003/07/24 17:09:22 nitrox Exp $ 
  *
  * Authors: Fabrice Ollivier <cif@via.ecp.fr>
  *          Arnaud Schauly <gitan@via.ecp.fr>
@@ -51,10 +51,11 @@ using namespace std;
 void help(void)
 {
   printf("Options:\n" \
-  "-d : Use this to daemonize the process (run in the background)\n" \
-  "-f or -c: Use this to give a configuration file (default is %s)\n" \
-  "-h: Display this help\n" \
-  "-s: Display a dot for each packet sent\n",DEFAULT_CONF);
+  "  -d      Use this to daemonize the process (run in the background)\n" \
+  "  -f      Use this to give a configuration file (default is %s)\n" \
+  "  -c      Same as -f\n" \
+  "  -h      Display this help\n" \
+  "  -s      Display a dot for each packet sent\n",DEFAULT_CONF);
 }
 
 /*************************************************
@@ -75,23 +76,25 @@ int main(int argc, char *argv[])
 
     /* Parse the command line */
     sprintf(getopt_string,"dhsf:c:");
-    while(result !=-1)
+    while((result = getopt(argc,argv,getopt_string))>0)
     {
-        result=getopt(argc,argv,getopt_string);
-        if(result=='c' || result=='f')
+        switch(result)
         {
-            config->SetFile(optarg);
-        }
-	if(result=='s')
-            config->SetDotMode(true);
-        if(result=='d')
-        {
-            config->SetDaemonMode(true);
-        }
-        if(result=='h')
-        {
-            help();
-            return(0);
+            case 'c':
+            case 'f':
+                config->SetFile(optarg);
+                break;
+            case 's':
+                config->SetDotMode(true);
+                break;
+            case 'd':
+                config->SetDaemonMode(true);
+                break;
+            case 'h':
+                help();
+                return ( 0 );
+            default:
+                return ( -1 );
         }
     }
 
@@ -114,20 +117,20 @@ int main(int argc, char *argv[])
     broadcast = new Broadcast(config->GetTTL());
     if(config->GetIPVersion() == 6)
     {
-	fprintf(stdout,"+ Using IPv6\n");
-	i_init_status=broadcast->Initv6(config->GetScope());
+        fprintf(stdout,"+ Using IPv6\n");
+        i_init_status=broadcast->Initv6(config->GetScope());
     }
     else
     {
-	fprintf(stdout,"+ Using IPv4\n");
-	i_init_status=broadcast->Initv4(); 
-    }    
-   
+        fprintf(stdout,"+ Using IPv4\n");
+        i_init_status=broadcast->Initv4(); 
+    }
+
 
     if(i_init_status)
     {
-	fprintf(stderr,"- Network initialization failed. Aborting\n");
-	return -1;
+        fprintf(stderr,"- Network initialization failed. Aborting\n");
+        return -1;
     }
 
     /* Forking if necessary */
@@ -150,14 +153,14 @@ int main(int argc, char *argv[])
             message->AddProgram(config->Programs[i]);
             /* Send the message */
             if(broadcast->Send( message , config->GetIPVersion() ))
-		fprintf(stderr,"- Message send failed\n");
+            fprintf(stderr,"- Message send failed\n");
             /* Delete the message */
             delete message;
-            if(config->GetDotMode()) 
-		    fprintf(stdout,".");
+            if(config->GetDotMode())
+                fprintf(stdout,".");
 
         }
-	fflush(stdout);
+        fflush(stdout);
         /* Wait for next sending */
         sleep(SAP_DELAY);
     }
